@@ -1,21 +1,25 @@
 # Estimation, Copyright (c) 2001-2004 by David R. Bickel.
-# DifferenceTests divided into DiffTests, MultTests, and TestStats on 7/29/02.
+# Last modified by David R. Bickel on 3/27/04.
 # DifferenceTests, Copyright (c) 2001-2003 by David R. Bickel.
+# DifferenceTests divided into DiffTests, MultTests, and TestStats on 7/29/02.
+# Created by David R. Bickel on 11/30/01.
+
 # 11/9/02. bayes.desirability() corrected. See 'Notes on R FDR.doc'.
 # 8/7/02. 'clip' changed to 'crop' throughout.
-
 # 4/26/02. grenander.mode added.
 # 4/25/02. winsorize option added to clipped.mean; clipped.range modified to ensure winsorize=FALSE; clipped.sd added.
 # 4/24/02. winsorized.sd and winsorized.mean added.
 # 4/8/02. trimmed.sd and trimmed.mean added.
 # 4/1/02. Functions depending on clip.vector added.
 # 2/28/02. trimmed.vector.skews and trimmed.vector.skews.matrix added.
-# Created by David R. Bickel on 11/30/01.
 
+print('loading Estimation.r')
 source("General.r")
 library(modreg)  # for smooth.spline
 #library(stepfun)  # for ecdf
 
+cv <- function(x){m <- mean(x); s <- sd(x); c(n = length(x), m = m, s = s, cv = s/m)}
+
 se.mean <- function(x, ...){sd(x, ...)/sqrt(length(x))}
 
 med<-function(x){if(length(x)<1) NaN else median(x)}
@@ -640,7 +644,7 @@ new.lag.table <- function(vectorRows, reference.vector = NULL, alternative = c("
 y.lag.p.value <- function(x, y, y.lag, nresample, x.is.reference = FALSE, max.abs.lag = default.max.abs.lag(length(x)), y.lags = (-max.abs.lag):(max.abs.lag), alternative = c("two.sided", "less", "greater"), ...)
 {
   alternative <- match.arg(alternative)
-  stopifnot(length(x) == length(y))
+  if(length(x) != length(y)) {print('y.lag.p.value error: length(x) != length(y)'); browser()}
   stopifnot(y.lag >= min(y.lags) && y.lag <= max(y.lags))
   sd.ratio <- max(sd(x), sd(y)) / min(sd(x), sd(y))
   if(sd.ratio >= 2) warning(paste('equality of standard deviations violated: sd.ratio==', sd.ratio))
